.. _api_geometry_sphere:

.. currentmodule:: microstructpy.geometry

microstructpy.geometry.Sphere
=============================

.. autoclass:: Sphere
    :members:
    :undoc-members:
    :inherited-members:
    :show-inheritance: